Display text on LCD displays (even on multiple ones). Allow to create windows (frames) on display, and to combine them (split, add, duplicate, scroll). See http://mbed.org/users/hlipka/notebook/lcdwindow/ for more information.

Dependents:   Mbell

Revision:
2:5ac5bab7daaf
Parent:
1:65f72ed914fa
Child:
3:e5d5e2fe4bf6
--- a/dogm_spi.h	Tue Nov 16 20:49:18 2010 +0000
+++ b/dogm_spi.h	Sat Nov 27 22:54:13 2010 +0000
@@ -38,16 +38,18 @@
 {
     public:
         /**
          * @param width number of chars per line
          * @param height number of lines (currently only 1 and 2 work)
          * @param the SPI object used for sending data (set to 1MHz)
          * @param enable the pin name for the enable line (0=active, connected to /CSB)
          * @param rs the pin name for the register select line (0=cmd, 1=data)
         */
-        DogmLCDSPI(unsigned int width, unsigned int height, SPI *spi, PinName enable, PinName rs); 
+        DogmLCDSPI(unsigned int columns, unsigned int rows, SPI *spi, PinName enable, PinName rs); 
         virtual void init();
-        virtual void writeText(const unsigned int line, const unsigned int pos, const char text[]);
+        virtual void writeText(const unsigned int column, const unsigned int row, const char text[]);
         virtual void clear();
+        virtual void character(int column, int row, int c);
+
 };
 
 #endif
@@ -38,16 +38,18 @@
     public:
         /**
-         * @param width number of chars per line
-         * @param height number of lines (currently only 1 and 2 work)
+         * @param columns number of chars per line
+         * @param rows number of lines (currently only 1 and 2 work)
          * @param the SPI object used for sending data (set to 1MHz)
          * @param enable the pin name for the enable line (0=active, connected to /CSB)
\ No newline at end of file